@@ -1,5 +1,5 @@
 __author__ = "Yoda"
 __email__ = "yodarlswitch@gmail.com"
-__version__ = "0.0.9"
-__url__ = "https://github.com/YodaPY/verox-ipc"
+__version__ = "0.0.10"
+__url__ = "https://github.com/YodaPY/verox"
 __license__ = "MIT"
